@@ -34,24 +34,17 @@ class Inserter(
     Entity,
 ):
     """
-    Inserter Entity prototype.
+    An entity that can move items between machines.
 
     .. NOTE::
 
         In Factorio, the ``Inserter`` prototype includes both regular and filter
         inserters. In Draftsman, inserters are split into two different classes,
         :py:class:`~.Inserter` and :py:class:`~.FilterInserter`
-
-    .. seealso::
-
-        :py:class:`~.FilterInserter`
     """
 
     def __init__(self, name=inserters[0], **kwargs):
         # type: (str, **dict) -> None
-        """
-        TODO
-        """
         super(Inserter, self).__init__(name, inserters, **kwargs)
 
         for unused_arg in self.unused_args:
